labeltools.color_chord_note_heads_in_expr_by_pitch_class_color_map
==================================================================

.. autofunction:: abjad.tools.labeltools.color_chord_note_heads_in_expr_by_pitch_class_color_map.color_chord_note_heads_in_expr_by_pitch_class_color_map
